@@ -128,7 +128,7 @@ impl Options {
     }
 
     pub fn config_path() -> Option<std::path::PathBuf> {
-        let config_dir = match dirs_next::config_dir() {
+        let config_dir = match dirs::config_dir() {
             Some(dir) => dir.join("irust"),
             None => return None,
         };
